const express = require('express');
const router = express.Router();
const adminController = require('../controllers/adminController');
const { protect } = require('../middleware/authMiddleware');
const adminMiddleware = require('../middleware/adminMiddleware');

// Все маршруты защищены middleware для проверки авторизации и прав администратора
router.use(protect, adminMiddleware);

// Маршруты для управления пользователями
router.get('/users', adminController.getAllUsers);
router.get('/users/:id', adminController.getUserDetails);
router.put('/users/:id/toggle-active', adminController.toggleUserActive);

// Маршруты для просмотра статистики
router.get('/statistics', adminController.getAppStatistics);

// Маршруты для просмотра диалогов и сообщений
router.get('/conversations', adminController.getAllConversations);
router.get('/conversations/:id/messages', adminController.getConversationMessages);

module.exports = router;